@@ -40,7 +40,7 @@ mapb_rgb = { 'red'   : ((0.0, 0.0, 0.0),
 #BLUE:
 #(0,0)(0.25,1)(0.5,0)(0.75,0)(1,1)
 
-mapb = LinearSegmentedColormap('b',mapb_rgb)
+mapb = LinearSegmentedColormap('b_ds9',mapb_rgb)
 plt.register_cmap(cmap=mapb)
 
 def ellipse (x0, y0, sma, eps, pa, step=400,
@@ -464,7 +464,7 @@ def figure(image, cent=[0,0], delta=[0,0], limt=[0,0,0], cmap=['jet'],
 
     if cent[0]  == 0 and cent[1]  == 0 :
        cent[0]  = ima.shape[1]*0.5 ; cent[1]  = ima.shape[0]*0.5
-    
+
     x = delta[0]*scale
     y = delta[1]*scale
 
@@ -482,7 +482,7 @@ def figure(image, cent=[0,0], delta=[0,0], limt=[0,0,0], cmap=['jet'],
     ima1 = ima[l3:l4+1, l1:l2+1]
 
     if cont != 'none':
-
+        #print ("The contours were acitvated for {}".format(str(image)))
         temp = np.copy(ima1)
         if imax == 'no':
             imax = np.amax(temp)
@@ -495,12 +495,15 @@ def figure(image, cent=[0,0], delta=[0,0], limt=[0,0,0], cmap=['jet'],
                 kernel = Gaussian2DKernel(x_stddev=sigmag)
             else:
                 kernel = Gaussian2DKernel(stddev=sigmag)
+            print ('\nIn order to plot the contours was applied a Gaussian' +
+                   + ' smoothing')
             smooth = convolve(temp, kernel)
             smooth[np.isnan(temp)]=np.nan
         else:
             smooth = np.copy(temp)
-            print ('It was not performed a smoothing for contours')
-        print('Contour intesities: ', nivels)
+            print ('\nIn order to plot the contours was not applied a Gaussian'+
+                    ' smoothing')
+        print('Contour intensities: ', nivels)
         CS = AX.contour(smooth, nivels, origin='lower', cmap=None,
                        extent=aextend, colors=contc, linestyles=contls)
 
@@ -609,7 +612,10 @@ def callf(image) :
     global ima_xy, ima_array
 
     ima_arrayn = fits.open(image)
-    ima_array = ima_arrayn[0].data
+    if image.split('.')[-1]=='fits':
+        ima_array = ima_arrayn[0].data
+    else:
+        ima_array = ima_arrayn[1].data
     ly, lx = np.shape(ima_array)
     x = np.arange(lx)
     y = np.arange(ly)
